import os
import boto3
from . import log_handler

logger = log_handler.logger

users_table_suffix = os.environ['USERS_TABLE_SUFFIX']
role_permissions_table_suffix = os.environ['ROLE_PERMISSIONS_TABLE_SUFFIX']

dynamodb = boto3.resource('dynamodb')

def check_permission(tenant, current_user_id, table, http_method):
    try: 
        users_table_name = tenant + users_table_suffix
        role_permissions_table_name = tenant + role_permissions_table_suffix

        users_table = dynamodb.Table(users_table_name)
        role_permissions_table = dynamodb.Table(role_permissions_table_name)

        users_data = users_table.get_item(Key={'userId': current_user_id})
        
        role_permissions_data = role_permissions_table.get_item(
            Key={
                'roleId': users_data['Item']['roleId'],
                'tableName': table
            }
        )
    except Exception as e:
        logger.error('error occured when checking prmission %s', e)
        return False

    if "Item" in role_permissions_data:
        return role_permissions_data['Item'][http_method]
    else:
        return False


import requests
import os
from . import log_handler

logger = log_handler.logger


endpoint = os.environ['USER_INFO_ENDPOINT']

def get_user_info(event):
    try:
        headers = {"Authorization": "Bearer " + event['headers']['Authorization']}
        tenant = requests.get(endpoint, headers=headers).json()["custom:tenant_id"]
        current_user_id = requests.get(endpoint, headers=headers).json()["sub"]
        current_user_name = requests.get(endpoint, headers=headers).json()["username"]
        
        return tenant, current_user_name, current_user_id
        
    except Exception as e:
        logger.error("error occured retrieving tenant data  %s....",str(e))
        
        return None, None, None
        


from setuptools import setup, find_packages

setup(
    name='keliya_lib',
    version='0.2.1',
    packages=find_packages(),
    install_requires=[
        'requests',
        'boto3'
    ],
    author='Erandra Jayasundara',
    author_email='erandraj@gmail.com',
    description='AWS Lambda helpers',
    license='MIT'
)

#python3 setup.py sdist bdist_wheel
#twine upload dist/*



import logging

logger = logging.getLogger()
logger.setLevel(logging.INFO)

def format_logs(http_method, user):
    myFormatter = logging.Formatter('[%(levelname)-8s] %(asctime)s ['+http_method+'] -- [USER:'+user+'] -- %(message)s')
    handler = logging.StreamHandler()
    handler.setFormatter(myFormatter)
    logger.addHandler(handler)